summaryrefslogtreecommitdiff
path: root/src_ui_overrides
diff options
context:
space:
mode:
authorRaman Tenneti <rtenneti@google.com>2020-08-03 12:54:21 -0700
committerRaman Tenneti <rtenneti@google.com>2020-08-04 00:35:03 +0000
commitab98166c36f2955359ccdf31defe0678f66bdd99 (patch)
tree09c2f40984bac5ce24b0570ba3a8fbc287dd2e59 /src_ui_overrides
parent12e59e9a66882d67687739cfd5be81e9beae790e (diff)
downloadLauncher3-ab98166c36f2955359ccdf31defe0678f66bdd99.tar.gz
AOSP/Launcher3 - Update language to comply with Android's inclusive language guidance.
See https://source.android.com/setup/contribute/respectful-code for reference BUG=161896447 Test: make and Presubmit verify. Change-Id: I44e903046dd4cd9c7c07872fc56a8d552eb09522
Diffstat (limited to 'src_ui_overrides')
-rw-r--r--src_ui_overrides/com/android/launcher3/uioverrides/dynamicui/ColorExtractionAlgorithm.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/src_ui_overrides/com/android/launcher3/uioverrides/dynamicui/ColorExtractionAlgorithm.java b/src_ui_overrides/com/android/launcher3/uioverrides/dynamicui/ColorExtractionAlgorithm.java
index 5a1f9caa5d..780a0f0372 100644
--- a/src_ui_overrides/com/android/launcher3/uioverrides/dynamicui/ColorExtractionAlgorithm.java
+++ b/src_ui_overrides/com/android/launcher3/uioverrides/dynamicui/ColorExtractionAlgorithm.java
@@ -21,16 +21,16 @@ import android.util.Log;
import android.util.Pair;
import android.util.Range;
+import androidx.annotation.NonNull;
+import androidx.annotation.Nullable;
+import androidx.core.graphics.ColorUtils;
+
import com.android.launcher3.Utilities;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;
-import androidx.annotation.NonNull;
-import androidx.annotation.Nullable;
-import androidx.core.graphics.ColorUtils;
-
/**
* Implementation of tonal color extraction
**/
@@ -69,7 +69,7 @@ public class ColorExtractionAlgorithm {
// palettes. The best fit is tweaked to be closer to the source color
// and replaces the original palette
// Get the most preeminent, non-blacklisted color.
Integer bestColor = 0;
final float[] hsl = new float[3];
for (int i = 0; i < mainColorsSize; i++) {
@@ -78,7 +78,7 @@ public class ColorExtractionAlgorithm {
Color.blue(colorValue), hsl);
// Stop when we find a color that meets our criteria
- if (!isBlacklisted(hsl)) {
+ if (!isDisallowed(hsl)) {
bestColor = colorValue;
break;
}
@@ -167,12 +167,12 @@ public class ColorExtractionAlgorithm {
}
/**
* Checks if a given color exists in the blacklist
* @param hsl float array with 3 components (H 0..360, S 0..1 and L 0..1)
* @return true if color should be avoided
*/
- private boolean isBlacklisted(float[] hsl) {
- for (ColorRange badRange: BLACKLISTED_COLORS) {
+ private boolean isDisallowed(float[] hsl) {
+ for (ColorRange badRange: DISALLOWED_COLORS) {
if (badRange.containsColor(hsl[0], hsl[1], hsl[2])) {
return true;
}
@@ -592,7 +592,7 @@ public class ColorExtractionAlgorithm {
);
@SuppressWarnings("WeakerAccess")
- static final ColorRange[] BLACKLISTED_COLORS = new ColorRange[] {
+ static final ColorRange[] DISALLOWED_COLORS = new ColorRange[] {
// Red
new ColorRange(
@@ -69,7 +69,7 @@ public class ColorExtractionAlgorithm {
// palettes. The best fit is tweaked to be closer to the source color
// and replaces the original palette
- // Get the most preeminent, non-blacklisted color.
+ // Get the most preeminent, non-disallowed color.
Integer bestColor = 0;
final float[] hsl = new float[3];
@@ -167,12 +167,12 @@ public class ColorExtractionAlgorithm {
}
/**
- * Checks if a given color exists in the blacklist
+ * Checks if a given color exists in the disallowed_colors list.
* @param hsl float array with 3 components (H 0..360, S 0..1 and L 0..1)
* @return true if color should be avoided